pub struct UserMasterPasswordRegistrationRequest {Show 14 fields
pub email: String,
pub salt: String,
pub master_password: String,
pub master_password_hint: Option<String>,
pub email_verification_token: Option<String>,
pub sales_assisted_token: Option<String>,
pub organization_user_id: Option<OrganizationId>,
pub org_invite_token: Option<String>,
pub org_sponsored_free_family_plan_token: Option<String>,
pub accept_emergency_access_invite_token: Option<String>,
pub accept_emergency_access_id: Option<UserId>,
pub provider_invite_token: Option<String>,
pub provider_user_id: Option<UserId>,
pub open_org_invite: Option<RegistrationFinishOpenOrgInviteData>,
}Expand description
Request parameters for master password registration
Fields
email: StringEmail for the account being initialized
salt: StringSalt for master password hashing
master_password: StringMaster password for the account
master_password_hint: Option<String>Optional hint for the master password
email_verification_token: Option<String>Optional token for email verification
sales_assisted_token: Option<String>Optional token for sales-assisted trial/registration
organization_user_id: Option<OrganizationId>Optional organization user ID for organization invitations
org_invite_token: Option<String>Optional direct organization invite token for joining an organization
org_sponsored_free_family_plan_token: Option<String>Optional token for sponsored free family plan
accept_emergency_access_invite_token: Option<String>Optional token for accepting emergency access invitation
accept_emergency_access_id: Option<UserId>Optional emergency access ID for accepting emergency access invitation
provider_invite_token: Option<String>Optional provider invite token for joining as a provider
provider_user_id: Option<UserId>Optional provider user ID for provider invitations
open_org_invite: Option<RegistrationFinishOpenOrgInviteData>Optional open-organization-invite identifiers when finishing registration with an open organization invite link in client state.